.. image:: https://travis-ci.org/asphalt-framework/asphalt-mailer.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt-mailer
  :alt: Build Status
.. image:: https://coveralls.io/repos/asphalt-framework/asphalt-mailer/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/asphalt-framework/asphalt-mailer?branch=master
  :alt: Code Coverage

This Asphalt framework component provides a means for sending email from Asphalt applications.

Project links
-------------

* `Documentation`_
* `Help and support`_
* `Source code`_
* `Issue tracker`_

.. _Documentation: http://asphalt-mailer.readthedocs.org/en/latest/
.. _Help and support: https://github.com/asphalt-framework/asphalt/wiki/Help-and-support
.. _Source code: https://github.com/asphalt-framework/asphalt-mailer
.. _Issue tracker: https://github.com/asphalt-framework/asphalt-mailer/issues
